@@ -15,11 +15,33 @@ class YearFilters:
     """
     weekNumberStart: int  # week to start at (inclusive)
     weekNumberEnd: int  # week to end at (inclusive)
-    includeMatchupTypes: list[MatchupType]  # include matchups of these types
-    includeMultiWeekMatchups: bool = True
-    onlyChampionship: bool = False
-    onlyPostSeason: bool = False
-    onlyRegularSeason: bool = False
+    includeMultiWeekMatchups: bool = True  # whether to include multi-week matchups or not
+    onlyChampionship: bool = False  # only include championship weeks
+    onlyPostSeason: bool = False  # only include playoff weeks
+    onlyRegularSeason: bool = False  # only include regular season weeks
+
+    @property
+    def includeMatchupTypes(self) -> list[MatchupType]:
+        if self.onlyChampionship:
+            return [MatchupType.CHAMPIONSHIP]
+        elif self.onlyPostSeason:
+            return [MatchupType.PLAYOFF, MatchupType.CHAMPIONSHIP]
+        elif self.onlyRegularSeason:
+            return [MatchupType.REGULAR_SEASON]
+        else:
+            return [MatchupType.REGULAR_SEASON, MatchupType.PLAYOFF, MatchupType.CHAMPIONSHIP]
+
+    @classmethod
+    def preferredOrderWithTitle(cls, year: Year, **kwargs) -> list[tuple[str, Any]]:
+        yearFilters = YearFilters.getForYear(year, **kwargs)
+        return [
+            ("Week Number Start", yearFilters.weekNumberStart),
+            ("Week Number End", yearFilters.weekNumberEnd),
+            ("Only Regular Season", yearFilters.onlyRegularSeason),
+            ("Only Post Season", yearFilters.onlyPostSeason),
+            ("Only Championship", yearFilters.onlyChampionship),
+            ("Include Multi-Week Matchups", yearFilters.includeMultiWeekMatchups)
+        ]
 
     @classmethod
     def getForYear(cls, year: Year, **kwargs) -> YearFilters:
@@ -36,26 +58,6 @@ class YearFilters:
 
         GeneralUtil.warnForUnusedKwargs(kwargsCopy)
 
-        if onlyChampionship:
-            includeMatchupTypes = [
-                MatchupType.CHAMPIONSHIP
-            ]
-        elif onlyPostSeason:
-            includeMatchupTypes = [
-                MatchupType.PLAYOFF,
-                MatchupType.CHAMPIONSHIP
-            ]
-        elif onlyRegularSeason:
-            includeMatchupTypes = [
-                MatchupType.REGULAR_SEASON
-            ]
-        else:
-            includeMatchupTypes = [
-                MatchupType.REGULAR_SEASON,
-                MatchupType.PLAYOFF,
-                MatchupType.CHAMPIONSHIP
-            ]
-
         ####################
         # validate filters #
         ####################
@@ -85,7 +87,7 @@ class YearFilters:
             raise InvalidFilterException("'weekNumberStart' cannot be greater than 'weekNumberEnd'.")
 
         return YearFilters(weekNumberStart=weekNumberStart, weekNumberEnd=weekNumberEnd,
-                           includeMatchupTypes=includeMatchupTypes, includeMultiWeekMatchups=includeMultiWeekMatchups,
+                           includeMultiWeekMatchups=includeMultiWeekMatchups,
                            onlyPostSeason=onlyPostSeason, onlyChampionship=onlyChampionship,
                            onlyRegularSeason=onlyRegularSeason)
 
