@@ -1,6 +1,6 @@
 import unittest
 
-from leeger.league_loader.YahooLeagueLoader import YahooLeagueLoader
+from leeger.league_loader import YahooLeagueLoader
 
 
 class TestESPNLeagueLoader(unittest.TestCase):
