@@ -9,11 +9,16 @@ class TestYearSettings(unittest.TestCase):
 
         self.assertTrue(yearSettings.leagueMedianGames)
 
-    def test_yearSettings_init_default(self):
+    def test_yearSettings_init_default_1(self):
         yearSettings = YearSettings()
 
         self.assertFalse(yearSettings.leagueMedianGames)
 
+    def test_yearSettings_init_default_2(self):
+        yearSettings = YearSettings(leagueMedianGames=None)
+
+        self.assertFalse(yearSettings.leagueMedianGames)
+
     def test_yearSettings_eq_equal(self):
         # create yearSettings 1
         yearSettings_1 = YearSettings(leagueMedianGames=True)
