@@ -138,6 +138,77 @@ class TestStatSheet(unittest.TestCase):
         self.assertIsNone(yearStatSheet.totalGames)
         self.assertIsNone(yearStatSheet.opponentLeagueMedianWins)
 
+        self.assertIsNone(yearStatSheet.ownerNames)
+        self.assertIsNone(yearStatSheet.years)
+
+    def test_yearStatSheet_ownerNamesAndYearsGiven(self):
+        from leeger.util.stat_sheet import yearStatSheet
+        owners, teams = getNDefaultOwnersAndTeams(2)
+
+        matchup = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=2)
+        week = Week(weekNumber=1, matchups=[matchup])
+        year = Year(yearNumber=2000, teams=teams, weeks=[week])
+
+        ownerNames = {
+            teams[0].id: "owner0",
+            teams[1].id: "owner1"
+        }
+
+        years = {
+            teams[0].id: 2000,
+            teams[1].id: 2000
+        }
+
+        yearStatSheet = yearStatSheet(year, ownerNames=ownerNames, years=years)
+
+        self.assertIsInstance(yearStatSheet, YearStatSheet)
+        self.assertIsInstance(yearStatSheet.gamesPlayed, dict)
+        self.assertIsInstance(yearStatSheet.wins, dict)
+        self.assertIsInstance(yearStatSheet.losses, dict)
+        self.assertIsInstance(yearStatSheet.ties, dict)
+        self.assertIsInstance(yearStatSheet.winPercentage, dict)
+        self.assertIsInstance(yearStatSheet.wal, dict)
+        self.assertIsInstance(yearStatSheet.walPerGame, dict)
+
+        self.assertIsInstance(yearStatSheet.awal, dict)
+        self.assertIsInstance(yearStatSheet.awalPerGame, dict)
+        self.assertIsInstance(yearStatSheet.opponentAWAL, dict)
+        self.assertIsInstance(yearStatSheet.opponentAWALPerGame, dict)
+
+        self.assertIsInstance(yearStatSheet.smartWins, dict)
+        self.assertIsInstance(yearStatSheet.smartWinsPerGame, dict)
+        self.assertIsInstance(yearStatSheet.opponentSmartWins, dict)
+        self.assertIsInstance(yearStatSheet.opponentSmartWinsPerGame, dict)
+
+        self.assertIsInstance(yearStatSheet.pointsScored, dict)
+        self.assertIsInstance(yearStatSheet.pointsScoredPerGame, dict)
+        self.assertIsInstance(yearStatSheet.opponentPointsScored, dict)
+        self.assertIsInstance(yearStatSheet.opponentPointsScoredPerGame, dict)
+
+        self.assertIsInstance(yearStatSheet.scoringShare, dict)
+        self.assertIsInstance(yearStatSheet.opponentScoringShare, dict)
+        self.assertIsInstance(yearStatSheet.maxScoringShare, dict)
+        self.assertIsInstance(yearStatSheet.minScoringShare, dict)
+
+        self.assertIsInstance(yearStatSheet.maxScore, dict)
+        self.assertIsInstance(yearStatSheet.minScore, dict)
+
+        self.assertIsInstance(yearStatSheet.scoringStandardDeviation, dict)
+
+        self.assertIsInstance(yearStatSheet.plusMinus, dict)
+
+        self.assertIsInstance(yearStatSheet.teamScore, dict)
+        self.assertIsInstance(yearStatSheet.teamSuccess, dict)
+        self.assertIsInstance(yearStatSheet.teamLuck, dict)
+
+        self.assertIsInstance(yearStatSheet.ownerNames, dict)
+        self.assertIsInstance(yearStatSheet.years, dict)
+
+        # check optional stats are None
+        self.assertIsNone(yearStatSheet.leagueMedianWins)
+        self.assertIsNone(yearStatSheet.totalGames)
+        self.assertIsNone(yearStatSheet.opponentLeagueMedianWins)
+
     def test_yearStatSheet_leagueMedianGamesIsTrue(self):
         from leeger.util.stat_sheet import yearStatSheet
         owners, teams = getNDefaultOwnersAndTeams(2)
